@@ -1,7 +1,7 @@
 #' Step 1 of PRC-LMM (estimation of the linear mixed models)
 #'
 #' This function performs the first step for the estimation
-#' of the PRC-LMM model proposed in Signorelli et al. (2020, 
+#' of the PRC-LMM model proposed in Signorelli et al. (2021, 
 #' in review)
 #' 
 #' @param y.names character vector with the names of the
@@ -65,7 +65,7 @@
 #' @seealso \code{\link{simulate_prclmm_data}},
 #' \code{\link{summarize_lmms}} (step 2),
 #' \code{\link{fit_prclmm}} (step 3),
-#' \code{\link{performance_prclmm}}
+#' \code{\link{performance_prc}}
 #' 
 #' @examples
 #' # generate example data
@@ -155,6 +155,7 @@ fit_lmms = function(y.names, fixefs, ranefs, long.data,
   check4 = identical(temp1, temp2)
   if (!check4) stop('id values are different in long.data and surv.data')  
   # remove all longitudinal measurements after t
+  t.from.base = deparse(substitute(t.from.base))
   temp = prepare_longdata(df = long.data, subj.id = id, 
             t.from.base = t.from.base, survtime = surv.data$time, 
             verbose = verbose)
@@ -267,8 +268,8 @@ fit_lmms = function(y.names, fixefs, ranefs, long.data,
                      silent = TRUE)
         }
         if (inherits(lmm, 'try-error')) {
-          warning(paste('bootstrap sample', b,
-            '= the LMM could be fitted for response', y.names[i]), 
+          warning(paste('Bootstrap sample', b,
+            ': the LMM could not be fitted for response', y.names[i]), 
             immediate. = TRUE)
         }
         lmm
